#[repr(i32)]pub enum TextDocumentSaveReason {
SaveReasonManual = 0,
SaveReasonAfterDelay = 1,
SaveReasonFocusOut = 2,
}Expand description
Text document save reason.
Variants
Implementations
Sourceimpl TextDocumentSaveReason
impl TextDocumentSaveReason
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of TextDocumentSaveReason.
Sourcepub fn from_i32(value: i32) -> Option<TextDocumentSaveReason>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<TextDocumentSaveReason>
Converts an i32 to a TextDocumentSaveReason, or None if value is not a valid variant.
Sourceimpl TextDocumentSaveReason
impl TextDocumentSaveReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.