#[repr(i32)]pub enum ViewColumn {
Undefined = 0,
Active = 1,
One = 2,
Two = 3,
Three = 4,
Four = 5,
Five = 6,
Six = 7,
Seven = 8,
Eight = 9,
Nine = 10,
}Expand description
A view column (editor location).
Variants
Undefined = 0
Active = 1
One = 2
Two = 3
Three = 4
Four = 5
Five = 6
Six = 7
Seven = 8
Eight = 9
Nine = 10
Implementations
Sourceimpl ViewColumn
impl ViewColumn
Sourceimpl ViewColumn
impl ViewColumn
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.